`octohatrack` takes a github repo name, and returns a list of every github
user that has interacted with a project, but has not committed code. 

More information can be found on the project page.  

This project is not affiliated with GitHub.
